==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ProvideCalculatorEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescription } from "./ProvideCalculatorEventArgsDescription";
/**
 * @hidden
 */
export let ProvideCalculatorEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ProvideCalculatorEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ProvideCalculatorEventArgsDescriptionMetadata.a == null) {
                ProvideCalculatorEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ProvideCalculatorEventArgsDescriptionMetadata.c(ProvideCalculatorEventArgsDescriptionMetadata.a);
            }
            if (a.j(ProvideCalculatorEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ProvideCalculatorEventArgsDescriptionMetadata.b(a);
            a.aa("ProvideCalculatorEventArgs", () => new ProvideCalculatorEventArgsDescription());
            a.z("ProvideCalculatorEventArgs", ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
    }
    ProvideCalculatorEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ProvideCalculatorEventArgsDescriptionMetadata, 'ProvideCalculatorEventArgsDescriptionMetadata');
    ProvideCalculatorEventArgsDescriptionMetadata.a = null;
    return ProvideCalculatorEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ProvideCalculatorEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescription } from "./ProvideCalculatorEventArgsDescription";
/**
 * @hidden
 */
export let ProvideCalculatorEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ProvideCalculatorEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ProvideCalculatorEventArgsDescriptionMetadata.a == null) {
                ProvideCalculatorEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ProvideCalculatorEventArgsDescriptionMetadata.c(ProvideCalculatorEventArgsDescriptionMetadata.a);
            }
            if (a.k(ProvideCalculatorEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ProvideCalculatorEventArgsDescriptionMetadata.b(a);
            a.ac("ProvideCalculatorEventArgs", () => new ProvideCalculatorEventArgsDescription());
            a.ab("ProvideCalculatorEventArgs", ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
    }
    ProvideCalculatorEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ProvideCalculatorEventArgsDescriptionMetadata, 'ProvideCalculatorEventArgsDescriptionMetadata');
    ProvideCalculatorEventArgsDescriptionMetadata.a = null;
    return ProvideCalculatorEventArgsDescriptionMetadata;
})();
